﻿/*** Name:      HighScores.cs
 *** Created:   11/27/2008, by: Roulaux, R
 *** Modified:  12/14/2008, by: van Vliembergen, RWL
 *** Source:    All functies voor highscores worden hierin toegepast. Toevoegen, opslaan en wissen.
 *** Copyright: (c) Gr2 Dev 2008
 */
using System;
using System.Collections.Generic;
using System.Text;

namespace Etaris.Core
{
    /// <summary>
    /// Beheert de topscores. De scores zijn altijd gesorteerd van hoog naar laag.
    /// Als er meer dan <i>maximumItems</i> scores zijn, dan wordt de laatste/laagste score verwijderd.
    /// </summary>
    [Serializable()]
    public class HighScores : List<Score>
    {
        /// <summary>
        /// Het maximale aantal topscores dat bijgehouden wordt.
        /// </summary>
        const int maximumItems = 10;

        /// <summary>
        /// Voegt een topscore toe.
        /// </summary>
        /// <param name="newScore">Een nieuwe score.</param>
        /// <returns>De positie waarop de score is toegevoegd.</returns>
        public int InsertScore(Score newScore)
        {
            //Init.
            int i;

            //Doorloop alle huidige/oude scores in de lijst.
            if (maximumItems != Count) throw new Exception("High Scores count is not " + maximumItems + ".");
            for (i = 0; i < maximumItems - 1; i++)
            {
                if (this[i].CompareTo(newScore) == 1) //Vergelijkt de nieuwe score met een oudere in de lijst.
                {
                    Insert(i, newScore);      //Voeg de nieuwe score toe.
                    RemoveAt(maximumItems);   //Verwijdert de laatste/laagste score.
                    return i; //Score op plaats i toegevoegd
                }
            }
            return -1; //Geen score toegevoegd...
        }

        /// <summary>
        /// Wist de topscores en vervangt ze met de default scorelijst.
        /// </summary>
        /// <param name="defaultScores">Lijst met default topscores.</param>
        /// <param name="copyOnlyOnError">Geeft aan of de lijst geleegd moet worden als het aantal scores niet correct is.</param>
        public void ClearList(HighScores defaultScores, bool copyOnlyOnError)
        {
            if (this.Count == maximumItems && copyOnlyOnError) return;

            //Gooi de oude lijst weg
            Clear();

            //Stel alle HighScores in op de standaard waarde.
            if (defaultScores.Count == maximumItems)
            {
                for(int i = 0; i < defaultScores.Count; i++)
                    Add(defaultScores[i]);
            }
            else
            {
                for (int i = maximumItems; i > 0; i--)
                    Add(new Score(0, "user"+i));
            }
        }
    }
}

