﻿/*** Name:      FrmConfigFile.cs
 *** Created:   12/4/2008, by: Hilkens, RGM
 *** Modified:  12/4/2008, by: Hilkens, RGM
 *** Source:    Speelstuktemplatesvenster.
 *** Copyright: (c) Gr2 Dev 2008
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Etaris.Core;
using System.Drawing.Drawing2D;

namespace Etaris.Gui
{
    /// <summary>
    /// Dit venster geeft de speelstuktemplates weer die zich in het configuratiebestand bevinden.
    /// </summary>
    /// <remarks>
    /// Dit venster tekent de speelstukken in twee kolommen.
    /// </remarks>
    public partial class FrmConfigFile : Form
    {
        int size = 20;          //Blokgrootte.
        int shadingSize = 8;

        /// <summary>
        /// Constructor. Initialiseert de klasse.
        /// </summary>
        public FrmConfigFile()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Berekent de noodzakelijke afmetingen om alle speelstuktemplates uit <i>config</i> weer te geven in dit venster.
        /// </summary>
        /// <param name="config">Een configuratiebestand.</param>
        /// <param name="columnWidth">Breedte van een enkele kolom.</param>
        /// <returns>Grootte van totale afbeelding.</returns>
        private Size CalculateSizes(ConfigurationFile config, out int columnWidth)
        {
            //Init.
            Size imgSize = new Size();
            int count = config.PieceTemplatesCount;
            int totalHeight = 0;
            int currentHeight = 0, temp;

            for (int i = 0; i < count; i++)
                totalHeight += size * config.GetPieceTemplate(i).Height + size;

            for (int i = 0; i < count; i++)
            {
                currentHeight += size * config.GetPieceTemplate(i).Height + size;
                if (currentHeight >= (totalHeight / 2 + 1))
                { imgSize.Height = currentHeight; break; }
            }

            config.GetMaximumPieceDimensions(out columnWidth, out temp);
            columnWidth *= size;
            imgSize.Width = columnWidth * 2 + size;

            //Finish.
            return imgSize;
        }

        /// <summary>
        /// Opent dit dialoogvenster en laat alle speelstuktemplates in <i>configurationFile</i> zien.
        /// </summary>
        /// <param name="configurationFile">Een configuratiebestand.</param>
        /// <param name="owner">Eigenaar van het dialoogvenster.</param>
        public void DrawPreviews(ConfigurationFile configurationFile, Form owner)
        {
            //Init.
            int count = configurationFile.PieceTemplatesCount;
            int columnWidth;
            Size imgSize = CalculateSizes(configurationFile, out columnWidth);
            dbBlockPreview.Image = new Bitmap(imgSize.Width, imgSize.Height);
            Graphics g = Graphics.FromImage(dbBlockPreview.Image);
            PieceTemplate template;
            Matrix m = new Matrix();
            Region reg = new Region(); reg.MakeInfinite();

            int left = 0;
            int top = 0;

            //Initialiseer de afbeelding.
            g.FillRegion(Brushes.White, reg);

            //Teken alle speelstuktemplates.
            for (int i = 0; i < count; i++)
            {
                m.Reset();

                template = configurationFile.GetPieceTemplate(i);

                if (template.Height * size + top > imgSize.Height)
                {
                    left = columnWidth + size;
                    top = 0;
                }
                
                m.Translate(left, top);
                g.Transform = m;

                template.SetPaintingSizes(size, shadingSize);
                template.Paint(g);
                top += template.Height * size + size;
            }

            //Finish.
            lblInfo.Text = "Total piece templates: " + count + ".";
            dbBlockPreview.ScrollBars = true; dbBlockPreview.Publish();
            ShowDialog(owner);
        }
    }
}
