﻿/*** Name:      FrmHighScores.cs
 *** Created:   9/25/2008, by: Hilkens, RGM
 *** Modified:  12/4/2008, by: Hilkens, RGM
 *** Source:    highscorevenster.
 *** Copyright: (c) Gr2 Dev 2008
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Etaris.Core;

namespace Etaris.Gui
{
    /// <summary>
    /// Topscorevenster.
    /// </summary>
    /// <remarks>Onder nieuwe invoer wordt verstaan het invullen van een naam 
    /// behorende bij een nieuwe topscore en het opslaan hiervan.</remarks>
    public partial class FrmHighScores : Form
    {
        bool isResized = false;
        bool isEditing = false;
        int newScore;

        /// <summary>
        /// Constructor. Initialiseert de klasse.
        /// </summary>
        public FrmHighScores()
        {
            InitializeComponent();
            FormClosing += new FormClosingEventHandler(FrmHighScores_FormClosing);
            Activated += new EventHandler(FrmHighScores_Activated);
        }

        /// <summary>
        /// Activeert de tekstinvoercontroller als een nieuwe invoer verwerkt moet worden.
        /// </summary>
        private void FrmHighScores_Activated(object sender, EventArgs e)
        {
            if (isEditing) txtName.Focus();
        }

        /// <summary>
        /// Voorkomt dat dit venster sluit als een nieuwe invoer verwerkt wordt.
        /// </summary>
        private void FrmHighScores_FormClosing(object sender, FormClosingEventArgs e)
        {
            e.Cancel = isEditing;
        }

        /// <summary>
        /// Leest de huidige topscores en schrijf deze naar een listView controller.
        /// </summary>
        private void LoadScores(int pos)
        {
            lvScores.Items.Clear();
            for (int i = 0; i < Settings.CurrentSettings.HighScoreList.Count; i++)
            {
                Score s = Settings.CurrentSettings.HighScoreList[i];
                ListViewItem highScore = new ListViewItem(s.Name);

                //Maakt score bold als het de aangegeven score is.
                if (i == pos) highScore.Font = new Font(lvScores.Font, FontStyle.Bold);

                highScore.SubItems.Add(s.FinalScore.ToString());
                lvScores.Items.Add(highScore);
            }
        }

        /// <summary>
        /// Past de afmetingen van de tabcontroller aan, zodat de tabknoppen niet zichtbaar zijn.
        /// </summary>
        private void ResizeTab()
        {
            //Init.
            int old = mainTab.Top;

            if (mainTab.Top >= 0)
            {
                mainTab.Top = 0 - tabScore.Top;
                mainTab.Height += (old - mainTab.Top);
                lvScores.Height += (old - mainTab.Top);
            }
            isResized = true;
        }

        /// <summary>
        /// Opent dit venster als een dialoogvenster met de huidige topscores.
        /// </summary>
        /// <param name="owner">Eigenaar van dit dialoogvenster.</param>
        /// <param name="pos">De positie van de nieuw toegevoegde score (als die er is).</param>
        public void ShowScoreList(Form owner,int pos)
        {
            if (!isResized) ResizeTab();
            AcceptButton = cmdOK;
            mainTab.TabPages.Clear();
            mainTab.TabPages.Add(tabScore);
            mainTab.SelectedTab = tabScore;
            LoadScores(pos);
            cmdOK.Focus(); //Zorg dat de toetsaanslagen opgevangen kunnen worden door de knop
            if (owner != null) ShowDialog(owner);
        }

        /// <summary>
        /// Opent dit venster en verwerkt een nieuwe invoer.
        /// </summary>
        /// <param name="score">De nieuwe score.</param>
        /// <param name="owner">Eigenaar van dit dialoogvenster.</param>
        public void AddNewScore(int score, Form owner)
        {
            if (!isResized) ResizeTab();
            AcceptButton = cmdSaveScore;
            isEditing = true;
            newScore = score;
            mainTab.TabPages.Clear();
            mainTab.TabPages.Add(tabNewScore);
            mainTab.SelectedTab = tabNewScore;
            if (owner != null) ShowDialog(owner);
        }

        /// <summary>
        /// Slaat de score inclusief naam definitief op.
        /// </summary>
        private void cmdSaveScore_Click(object sender, EventArgs e)
        {
            //Init.
            int pos;
            
            if (txtName.Text.Trim() == "") { MessageBox.Show("Please fill in your name.", Text, MessageBoxButtons.OK, MessageBoxIcon.Warning); return; }
            pos=Settings.CurrentSettings.HighScoreList.InsertScore(new Score(newScore, txtName.Text.Trim()));
            Settings.CurrentSettings.SaveSettings();
            isEditing = false;
            ShowScoreList(null,pos);
        }

        /// <summary>
        /// Zorgt ervoor dat de topscorelijst afsluit bij het induwen van een willekeurige toets (tenzij er een naam ingevoerd wordt)
        /// </summary>
        private void cmdOK_KeyDown(object sender, KeyEventArgs e)
        {
            this.Close();
        }
    }
}
